@@ -79,10 +79,10 @@ private:
   void DoInit() override
   {
     SetName("ComputePolylineFeatureFromImage");
-    SetDescription("This application compute for each studied polyline, contained in the input VectorData, the chosen descriptors.");
+    SetDescription("This application computes the chosen descriptors for each studied polyline contained in the input VectorData.");
 
     SetDocName("Compute Polyline Feature From Image");
-    SetDocLongDescription("The first step in the classifier fusion based validation is to compute, for each studied polyline, the chosen descriptors. ");
+    SetDocLongDescription("The first step in the classifier fusion based validation is to compute the chosen descriptors for each studied polyline. ");
     SetDocLimitations("Since it does not rely on streaming process, take care of the size of input image before launching application.");
     SetDocAuthors("OTB-Team");
     SetDocSeeAlso(" ");
