@@ -51,6 +51,9 @@ namespace Utils
   /** Function that prints nothing (useful to disable libsvm logs)*/
   void OTBCommon_EXPORT PrintNothing(const char *s);
 
+  extern OTBCommon_EXPORT bool const TrueConstant;
+
+  extern OTBCommon_EXPORT bool const FalseConstant;
 }
 
 } // namespace otb
