@@ -185,12 +185,12 @@ public:
   /** Make a DataObject of the correct type to be used as the specified
    * output.
    */
-  DataObjectPointer MakeOutput(DataObjectPointerArraySizeType idx) ITK_OVERRIDE;
+  DataObjectPointer MakeOutput(DataObjectPointerArraySizeType idx) override;
   using Superclass::MakeOutput;
 
-  void Reset(void) ITK_OVERRIDE;
+  void Reset(void) override;
 
-  void Synthetize(void) ITK_OVERRIDE;
+  void Synthetize(void) override;
 
   itkSetMacro(EnableMinMax, bool);
   itkGetMacro(EnableMinMax, bool);
@@ -216,19 +216,19 @@ public:
 protected:
   PersistentStreamingStatisticsVectorImageFilter();
 
-  ~PersistentStreamingStatisticsVectorImageFilter() ITK_OVERRIDE {}
+  ~PersistentStreamingStatisticsVectorImageFilter() override {}
 
   /** Pass the input through unmodified. Do this by Grafting in the
    *  AllocateOutputs method.
    */
-  void AllocateOutputs() ITK_OVERRIDE;
+  void AllocateOutputs() override;
 
-  void GenerateOutputInformation() ITK_OVERRIDE;
+  void GenerateOutputInformation() override;
 
-  void PrintSelf(std::ostream& os, itk::Indent indent) const ITK_OVERRIDE;
+  void PrintSelf(std::ostream& os, itk::Indent indent) const override;
 
   /** Multi-thread version GenerateData. */
-  void  ThreadedGenerateData(const RegionType& outputRegionForThread, itk::ThreadIdType threadId) ITK_OVERRIDE;
+  void  ThreadedGenerateData(const RegionType& outputRegionForThread, itk::ThreadIdType threadId) override;
 
 private:
   PersistentStreamingStatisticsVectorImageFilter(const Self &); //purposely not implemented
@@ -493,7 +493,7 @@ protected:
   StreamingStatisticsVectorImageFilter() {}
 
   /** Destructor */
-  ~StreamingStatisticsVectorImageFilter() ITK_OVERRIDE {}
+  ~StreamingStatisticsVectorImageFilter() override {}
 
 private:
   StreamingStatisticsVectorImageFilter(const Self &); //purposely not implemented
